IDmappingFunction <-
function(directory=NULL, tradfcompl=NULL, org=NULL, brainarray=NULL, uniprot=NULL){


#tradfcompl -> Mapping-file of the Unigene-Database
if(is.null(directory)){
tmpdir <- tempdir()
}
else{
setwd(directory)
}

if(is.null(tradfcompl)){

url <- "ftp://ftp.uniprot.org/pub/databases/uniprot/current_release/knowledgebase/idmapping/by_organism/"
txt = getURL(url)

if(is.null(org)) stop ("Please select an one of the following organism. org=ARATH, CAEEL, CHICK, DANRE, DICDI, DROME, ECOLI, HUMAN, MOUSE, RAT, SCHIPO, YEAST")

org <- toupper(org)  

if(org!="ARATH" && org!="CAEEL" && org!="HUMAN" && org!="CHICK" && org!="DANRE" && org!="DICDI" && org!="DROME" &&  org!="ECOLI" && org!="MOUSE" && org!="RAT" && org!="SCHIPO" && org!="YEAST") stop ("Please select an one of the following organism. org=ARATH, CAEEL, CHICK, DANRE, DICDI, DROME, ECOLI, HUMAN, MOUSE, RAT, SCHIPO, YEAST")

gst <- paste(org,"(.*?)idmapping.dat.gz", sep="")             

if(org=="RAT"){
  
  txt <- gsub("ARATH", "XXXXX", txt)
  
}

tm <- gregexpr(gst, txt)
fin <- regmatches(txt,tm)[[1]][1]

url <- paste(url, fin, sep="")

file <- basename(url)
download.file(url, file)
tradfcompl <- read.table((gzfile(file)), sep="\t")
}

else{
tradfcompl <- read.table(tradfcompl)
}

uniprotkbid.table <- tradfcompl[grep("UniProtKB.ID", tradfcompl[,2]),]

colnames(uniprotkbid.table) <- c("UniprotID", "ID", "UniProtKB.ID") 

kegg.table <- tradfcompl[grep("KEGG", tradfcompl[,2]),]

colnames(kegg.table) <- c("UniprotID", "ID", "KEGG") 

geneid.table <- tradfcompl[grep("GeneID", tradfcompl[,2]),]

colnames(geneid.table) <- c("UniprotID", "ID", "GeneID") 

unigene.table <- tradfcompl[grep("UniGene", tradfcompl[,2]),]

colnames(unigene.table) <- c("UniprotID", "ID", "UniGene") 

ensembl.table <- tradfcompl[grep("Ensembl", tradfcompl[,2] ),]

ensembl.table  <- ensembl.table[grep("_", ensembl.table[,2], invert=TRUE),]

colnames(ensembl.table) <- c("UniprotID", "ID", "Ensembl") 

#uniprotkbid.table <- read.table(uniprotkbid, col.names=c("UniprotID", "ID", "UniProtKB.ID"))

#kegg.table <- read.table(kegg, col.names=c("UniprotID", "ID", "KEGG"))

#geneid.table <- read.table(geneid, col.names=c("UniprotID", "ID", "GeneID"))

together_1 <- merge(uniprotkbid.table, kegg.table, by = intersect(names(uniprotkbid.table[1]), names(kegg.table[1])), all=TRUE)

subtogether_1 <- together_1[c(1,3,5)]

together_2 <- merge(subtogether_1, geneid.table, by = intersect(names(subtogether_1[1]), names(geneid.table[1])), all=TRUE)

together_3 <- together_2[c(1,5,3,2)]

together_4 <- merge(together_3, unigene.table, by = intersect(names(together_3[1]), names(unigene.table[1])), all=TRUE)

together_5 <- merge(together_4, ensembl.table, by = intersect(names(together_4[1]), names(ensembl.table[1])), all=TRUE)

final <- together_5[c(1,2,3,4,6,8)]

url <- "ftp://ftp.uniprot.org/pub/databases/uniprot/current_release/knowledgebase/idmapping/by_organism/"
txt = getURL(url)

referenceTable <- final

if(is.null(brainarray)){

  return(referenceTable)
}

else{
 
  hugene10st_Hs_ENSG_brain <- read.table(file=brainarray, header = TRUE, sep = "\t")
  #Removing _at values 
  hugene10st_Hs_ENSG_brain[,1]<-apply(hugene10st_Hs_ENSG_brain[,1,drop=FALSE], 2, function(x) gsub("_at" ,"", x))
  #head(hugene10st_Hs_ENSG_brain)
  # Probe.Set.Name Chr Chr.Strand Chr.From Probe.X Probe.Y Affy.Probe.Set.Name
  # 1 ENSG00000000003   X          - 99891796      84     347             8173941
  # 2 ENSG00000000003   X          - 99891792     815     792             8173941
  # 3 ENSG00000000003   X          - 99891741     381     944             8173941
  # 4 ENSG00000000003   X          - 99891735     809     475             8173941
  # 5 ENSG00000000003   X          - 99891659     620    1024             8173941
  # 6 ENSG00000000003   X          - 99891657     921     669             8173941
  ensg_affy <- hugene10st_Hs_ENSG_brain[,c(1,7)]
  colnames(ensg_affy) <- c("Ensembl", "Affy")
  
  final_pre <- merge(final, ensg_affy, by= intersect(names(final)[6], names(ensg_affy[1])),all=TRUE)
  
  final <- final_pre[, c(2,3,4,5,6,1,7)]
    
  uniprot.all.fasta <- readLines(uniprot)
  uniprot.all.fasta.sup <- uniprot.all.fasta[grep(">sp", uniprot.all.fasta)]
  uniprot.all.fasta.sup.pre <- gsub(" .*$", "", uniprot.all.fasta.sup)
  uniprot.all.fasta.sup.pre2 <- gsub(">sp", "", uniprot.all.fasta.sup.pre)
  uniprot.all.fasta.sup.pre3 <- strsplit(x=uniprot.all.fasta.sup.pre2, split="\\|")
  uniprot.swissprot <- matrix(nrow=length(uniprot.all.fasta.sup.pre3), ncol=2)
  for(i in 1:length(uniprot.all.fasta.sup.pre3)){
    uniprot.swissprot[i,1] <- uniprot.all.fasta.sup.pre3[[i]][2]
    uniprot.swissprot[i,2] <- uniprot.all.fasta.sup.pre3[[i]][3]
    
  }
  
  colnames(uniprot.swissprot) <- c("UniprotID", "UniProtKB.ID")
  
  final_swissprot_pre <- merge(final,y=uniprot.swissprot, by="UniprotID", all.x=FALSE)
  final_swissprot <- final_swissprot_pre[,c(1,2,3,5,4,6,7)]
  colnames(final_swissprot)[5] <- "UniProtKB.ID"
  
  result.list <- list()
  referenceTable <- final
  referenceTableAffy <- final_swissprot
  result.list[[1]] <- referenceTable
  result.list[[2]] <- referenceTableAffy
  
  names(result.list) <- c("referenceTable", "referenceTableAffy")
  
  return(result.list)
  
}


}
