createUnigeneDatabase <-
function(dbDriver=NULL, dbUser=NULL,dbHost=NULL,password=NULL, dbData=NULL, directory=NULL , species=NULL){

if(is.null(dbUser) ) stop ("Input dbUser is missing.")
if(is.null(dbHost) ) stop ("Input dbHost is missing.")
 #if(is.null(password) ) stop ("Input password is missing. If you do not have a password, please select ")
if(is.null(dbData) )stop ("Input dbData is missing.")
if(is.null(directory) )stop ("Please select directory of Unigene-files.")
if(is.null(species) )stop ("Define species.")
                             
drv <- dbDriver(dbDriver)

		if (is.null(password)){
		 con <- dbConnect(drv, user=dbUser,host=dbHost)
					}
		if (!is.null(password)) {
		con <- dbConnect(drv, user=dbUser,host=dbHost,password=password)
	  				}
dropDB <- paste("drop database if exists ", dbData,sep="")
createDB <- paste("create database ", dbData,sep="")
dbSendQuery(con,statement=dropDB)
dbSendQuery(con,statement=createDB)

dbDisconnect(con)


		if (is.null(password)){
		 con <- dbConnect(drv, user=dbUser,host=dbHost, dbname=dbData)
					}
		if (!is.null(password)) {
		con <- dbConnect(drv, user=dbUser,host=dbHost,password=password, dbname=dbData)
					}



setwd(directory)

libdata <- paste(directory, species, "libinfo.Rdata", sep="")
hsdata <- paste(directory, species, "data.Rdata", sep="")
estdata <- paste(directory, species, "ESTdata.Rdata", sep="")

load(libdata)
load(hsdata)
load(estdata)

#write.table(file="/tmp/libdata.csv", col.names = TRUE, row.names = FALSE,quote = FALSE, sep="\t",Libdata )

Libdata.frame <- as.data.frame(Libdata, stringsAsFactors=FALSE)


colnames(Libdata.frame) <- c("library_id", "title", "tissue", "verbatim_tissue", "verbatim_developmental_stage", "cell_line_source", "developmental_stage", "cancer_source", "vector")

createlibrary1 <- "drop table if exists library;"
createlibrary2 <-  "create table 
		library 
		(
		library_id int(5) unsigned NOT NULL, 
		title varchar(300) default NULL, 
		tissue varchar(200) default NULL, 
		verbatim_tissue varchar(300) default NULL, 
		verbatim_developmental_stage varchar(300) default NULL, 
		cell_line_source varchar(300) default NULL, 
		developmental_stage varchar(300) default NULL, 
		cancer_source varchar(200) default NULL, 
		vector varchar(200) default NULL, 
		PRIMARY KEY (library_id), 
		INDEX(tissue) 
		);"

dbSendQuery(con,statement=createlibrary1)
dbSendQuery(con,statement=createlibrary2)

dbWriteTable(con, "library" , Libdata.frame , sep="\t", row.names = FALSE,append=TRUE)
 
creategene1 <- "drop table if exists gene;"
creategene2 <- "create table 
		gene 
		(sec_gene int(5) unsigned NOT NULL auto_increment, 
		id varchar(10) NOT NULL, 
		title varchar(300) default NULL, 
		gene varchar(50) default NULL, 
		cytoband varchar(50) default NULL, 
		gene_id int(8) unsigned default NULL, 
		express varchar(2000) default NULL, 
		restrexpr varchar (300) default NULL, 
		chromosome varchar(2) default NULL, 
		PRIMARY KEY (sec_gene) 
		);"

dbSendQuery(con,statement=creategene1)
dbSendQuery(con,statement=creategene2)

Hsdata.frame <- as.data.frame(Hsdata, stringsAsFactors=FALSE)

dbWriteTable(con, "gene" , Hsdata.frame , sep="\t", row.names = FALSE,append=TRUE)

createest1 <- "drop table if exists est;"
createest2 <- "create table est 
		(
		sec_est int(6) unsigned NOT NULL auto_increment,
		sec_gene int(5) unsigned NOT NULL,
		library_id int(5) unsigned NOT NULL,
		clone varchar(100) default NULL,
		PRIMARY KEY (sec_est),
		INDEX(library_id)
		);"
#CONSTRAINT FOREIGN KEY (sec_gene) REFERENCES gene(sec_gene) ON DELETE CASCADE ON UPDATE CASCADE,
#CONSTRAINT FOREIGN KEY (library_id) REFERENCES library(library_id) ON DELETE CASCADE ON UPDATE CASCADE

dbSendQuery(con,statement=createest1)
dbSendQuery(con,statement=createest2)

Estdata.frame <- as.data.frame(Estdata, stringsAsFactors=FALSE)
rmd2 <- Estdata.frame[rowSums(is.na(Estdata.frame[,1:4]))!=4,]
Estdata.frame <- rmd2

Estdata.frame$sec_gene <- as.numeric(gsub(species, "", Estdata.frame$sec_gene))


dbWriteTable(con, "est" , Estdata.frame , row.names = FALSE,append=TRUE)


#--------------------------------------------------------------------------



createunensemble1 <- "drop table if exists ug_ensembl;"
createunensemble2 <- "create table 
			ug_ensembl
			(
			unigene varchar(10) NOT NULL,
			transcript varchar(15) default NULL,
			gene varchar(15) default NULL,
			PRIMARY KEY (unigene)
			);"

createunensemble1 <- dbSendQuery(con,statement=createunensemble1)
createunensemble2 <-dbSendQuery(con,statement=createunensemble2)

tissue1 <- "drop table if exists tissue;"
tissue2 <- "create table 
		tissue
		(
		sec_tissue int(3) unsigned NOT NULL auto_increment,
		description varchar(15) NOT NULL,
		PRIMARY KEY (sec_tissue)
		);"

#--Se rellena con tejido sano de adulto
tissue3 <- "insert into tissue select NULL, tissue from library group by tissue having tissue is not null;"

tissue1 <-dbSendQuery(con,statement=tissue1)
tissue2 <-dbSendQuery(con,statement=tissue2)
tissue3 <-dbSendQuery(con,statement=tissue3)

est_gene_tissue1 <- "drop table if exists gene_est_tissue;"
est_gene_tissue2 <- "create table gene_est_tissue
				select
g.id,g.gene,e.clone,l.cell_line_source,l.developmental_stage,l.tissue,l.cancer_source
				from
				gene g,
				est e,
				library l
				where
				g.sec_gene=e.sec_gene and
				e.library_id=l.library_id;"
		
est_gene_tissue3 <- "alter table gene_est_tissue add index(gene);"
est_gene_tissue4 <- "alter table gene_est_tissue add index(tissue);"
#est_gene_tissue5 <- "alter table gene_est_tissue add index(normal);"

est_gene_tissue1 <-dbSendQuery(con,statement=est_gene_tissue1)
est_gene_tissue2 <-dbSendQuery(con,statement=est_gene_tissue2)
est_gene_tissue3 <-dbSendQuery(con,statement=est_gene_tissue3)
est_gene_tissue4 <-dbSendQuery(con,statement=est_gene_tissue4)
#est_gene_tissue5 <-dbSendQuery(con,statement=est_gene_tissue5)

est_by_genetissue1 <- "drop table if exists est_by_genetissue;"
est_by_genetissue2 <- "create table est_by_genetissue
			select id,tissue,count(clone) 
			from gene_est_tissue 
			group by
			id,tissue;"
est_by_genetissue3 <- "delete from est_by_genetissue where id is null;"
est_by_genetissue4 <- "delete from est_by_genetissue where tissue is null;"

est_by_genetissue1 <-dbSendQuery(con,statement=est_by_genetissue1)
est_by_genetissue2 <-dbSendQuery(con,statement=est_by_genetissue2)
est_by_genetissue3 <-dbSendQuery(con,statement=est_by_genetissue3)
est_by_genetissue4 <-dbSendQuery(con,statement=est_by_genetissue4)

est_by_symboltissue1 <- "drop table if exists est_by_symboltissue;"

est_by_symboltissue1 <- "create table est_by_symboltissue
select gene,tissue,count(clone) num_ESTs
from gene_est_tissue
group by
gene,tissue
having gene is not null and
num_ESTs>0;"

est_by_symboltissue1 <-dbSendQuery(con,statement=est_by_symboltissue1)
}
