expParaGraph <-
function(igraph, expr, phenotype, dbDriver="MySQL", dbUser="root", dbHost="localhost", dbName="KeggSQL", password=password){
  
  #igraph <- compare.local.without$igraph.un; expr <- rma; phenotype <- ctyp2
  graphs <- NULL
  graph.names <- NULL
  mean.mmt <- NULL
  median.mmt <- NULL
  
  #ID Mapping of the EST files -> Ensembl 2 Uniprot_genename
    
  mart <- useMart(biomart="ensembl", dataset="hsapiens_gene_ensembl")
  
  mmt.id <- try(getBM(attributes = c("ensembl_gene_id", "uniprot_swissprot"), filters = "ensembl_gene_id", values=c(rownames(exprs(expr))), mart = mart), silent=TRUE)
  
  if(class(mmt.id)=="try-error"){
  
    mart <- useMart(biomart="ENSEMBL_MART_ENSEMBL", host="www.ensembl.org", path="/biomart/martservice", dataset="hsapiens_gene_ensembl")
    mmt.id <- getBM(attributes = c("ensembl_gene_id", "uniprot_swissprot"), filters = "ensembl_gene_id", values=c(rownames(exprs(expr))), mart = mart)
  
  }
  
  mmt.id <- subset(mmt.id, subset=mmt.id$uniprot_swissprot!="")
  m <- match(rownames(exprs(expr)), mmt.id$ensembl_gene_id)
  
  mmt.wids <- exprs(expr)
  
  rownames(mmt.wids) <- mmt.id$uniprot_swissprot[m]
  
  mmt.wids <- mmt.wids[rownames(mmt.wids)!="",]
  mmt.wids <- mmt.wids[!is.na(rownames(mmt.wids)),]
  
  
  dup <- mmt.wids[duplicated(rownames(mmt.wids)),]
  
  mmt.wids <- mmt.wids[!rownames(mmt.wids)%in%rownames(dup),]
  dsubm.final <- NULL
  
  for(rp in unique(rownames(dup))){ 
    
    dsub <- subset(dup, subset=rownames(dup)==rp)
    dsubm <- t(as.matrix(colMeans(dsub)))
    rownames(dsubm) <- rp
    
    
    if(rp == unique(rownames(dup))[1]){
      
      
      dsubm.final <- dsubm
      
    }
    
    else{
      
      dsubm.final <- rbind(dsubm.final, dsubm)
      
    }        
  }
  
  mmt.wids <- rbind(mmt.wids, dsubm.final)  
  
  #separating phenotypes
  phenotypes <- unique(as.character(pData(expr)[, names(pData(expr))%in%phenotype]))
  num <- as.character(pData(expr)[, names(pData(expr))%in%phenotype])
  
  sub <- list()
  for(kpheno in 1:length(phenotypes)){
    
                                      sub[[kpheno]] <- as.matrix(mmt.wids[,num%in%phenotypes[kpheno]])
                                      
                                      #Matrix for quantiles
                                      mmt <- matrix(ncol=length(quantile(sub[[kpheno]])), nrow=length((sub[[kpheno]])))
                                      colnames(mmt) <- names(quantile(sub[[kpheno]]))
                                      
                                      #median and mean of all the data set
                                      mean.mmt[kpheno] <- mean(sub[[kpheno]])
                                      median.mmt[kpheno] <- median(sub[[kpheno]])
                                      
                                      #zscore of every row of the subset
                                      zscore.mmt <- scale(sub[[kpheno]])
                                      attr(scale(sub[[kpheno]]), "scaled:center")
                                      attr(scale(sub[[kpheno]]), "scaled:scale")
                                      
                                      #all columns combined (sum) / number colums
                                      rowsum.mmt <- as.matrix(rowSums(sub[[kpheno]])/ncol(sub[[kpheno]]))
                                      colnames(rowsum.mmt) <- "mean.expr"
                                      zscore.rowsum.mmt <- scale(rowsum.mmt)
                                      attr(scale(rowsum.mmt), "scaled:center")
                                      attr(scale(rowsum.mmt), "scaled:scale")
                                      
                                      #Subsetting info of expression of Vertexces of the graph
                                      sub.vertexces <- subset(x=sub[[kpheno]], subset=rownames(sub[[kpheno]])%in%V(igraph)$name, drop=FALSE)
                                      
                                      #Vertexces which do not have a Expression / could not be mapped to the IDs of the microarrary
                                      notsub <- V(igraph)$name[!(V(igraph)$name%in%rownames(sub[[kpheno]]))]
                                      notsubm <- matrix(ncol=ncol(sub[[kpheno]]), nrow=length(notsub))
                                      colnames(notsubm) <- colnames(sub[[kpheno]])
                                      rownames(notsubm) <- notsub
                                      
                                      #combination of both matrixes
                                      comp <- rbind(sub.vertexces, notsubm)
                                      compdf <- as.data.frame(comp, stringsAsFactors=FALSE)
                                      
                                      names.compdf <- rownames(compdf)
                                      fin.names.compdf <- rownames(compdf)
                                      z <- 0
                                      para.list <- NULL
                                      fin <- NULL
                                      
                                      for(spara in names.compdf){
                                        
                                        
                                        
                                        if (spara%in%fin.names.compdf){
                                          
                                          z <- z+1
                                          
                                          pralogs <- try(searchParalogos(dbDriver=dbDriver, dbUser=dbUser, dbHost=dbHost, dbName=dbName, password=password, GeneID=spara), silent=TRUE)
                                          
                                          if(nrow(pralogs)>0){
                                            
                                            
                                            for (gr in 1:nrow(pralogs)){
                                              
                                              if(gr == 1){
                                                group <- paste("|", pralogs[[1]][gr], "|", sep="")
                                              }
                                              else{
                                                group <- paste(  group,pralogs[[1]][gr],"|", sep="")
                                              }  
                                              
                                            }
                                            
                                            
                                            
                                            
                                            #zscore for Paralogs in Graph
                                            subpra.gra <- subset(compdf, subset=rownames(compdf)%in%pralogs[,1])                             
                                            subpra.gra.rmean <-  as.matrix(rowMeans(subpra.gra))
                                            
                                            subpra.gra.rmean.wna <- subset(subpra.gra.rmean, !is.na(subpra.gra.rmean))
                                            subpra.gra.rmean.na <- subset(subpra.gra.rmean, is.na(subpra.gra.rmean))
                                            
                                            if(nrow(subpra.gra.rmean.wna)>0 ){
                                              subpra.gra.zscore <- scale(subpra.gra.rmean.wna)
                                                                                            subpra.gra.zscore[is.na(subpra.gra.zscore),] <- 0
                                              subpra.gra.zscore.mean <- attr(subpra.gra.zscore, "scaled:center")
                                              subpra.gra.zscore.scale <- attr(subpra.gra.zscore, "scaled:scale")
                                              
                                              if(nrow(subpra.gra.rmean.na) > 0){
                                                comp <- as.data.frame(cbind(subpra.gra.rmean, rbind(subpra.gra.zscore, subpra.gra.rmean.na),subpra.gra.zscore.mean,subpra.gra.zscore.scale, group), stringAsFactor=FALSE)
                                              }
                                              else{
                                                comp <- as.data.frame(cbind(subpra.gra.rmean.wna,subpra.gra.zscore, subpra.gra.zscore.mean,subpra.gra.zscore.scale, group), stringAsFactor=FALSE) 
                                                
                                              }
                                            }
                                            
                                            else{
                                              subpra.gra.zscore <- subpra.gra.rmean.na
                                              subpra.gra.zscore.mean <- "NA"
                                              subpra.gra.zscore.scale <- "NA"
                                              comp <- as.data.frame(cbind(subpra.gra.rmean, subpra.gra.zscore,subpra.gra.zscore.mean,subpra.gra.zscore.scale, group), stringAsFactors=FALSE)
                                            }                                                          
                                            
                                            
                                          }
                                          
                                          else{
                                            
                                            subpra.gra <- subset(compdf, subset=rownames(compdf)%in%spara) 
                                            if(nrow(subpra.gra)>0){
                                              subpra.gra.zscore.mean <- as.matrix(rowMeans(scale(subpra.gra))) 
                                              subpra.gra.zscore.scale <- 0
                                              group <- group <- paste("|",rownames(subpra.gra), "|", sep="")
                                              comp <- as.data.frame(cbind(subpra.gra.zscore.mean,subpra.gra.zscore.mean,subpra.gra.zscore.scale,subpra.gra.zscore.scale, group), stringAsFactors=FALSE) 
                                            }
                                          }
                                          
                                          names(comp) <- c("expression", "zscore-para", "mean-para", "sd-para", "Paralogs")
                                          para.list[[z]] <- comp
                                          
                                          fin.names.compdf <- fin.names.compdf[!fin.names.compdf%in%rownames(para.list[[z]])]
                                          
                                        } 
                                        
                                      }  
                                      
                                      para.list <- para.list[!duplicated(para.list)]
                                      
                                      fin <- NULL
                                      
                                      for(param in 1: length(para.list)){
                                        
                                        if(param==1){
                                          fin <- para.list[[param]]   
                                        }
                                        else{
                                          
                                          fin <- rbind(fin, para.list[[param]]) 
                                        }
                                        
                                      }
                                      
                                      mat <- match( V(igraph)$name, rownames(fin))
                                      
                                      suppressWarnings(for(i in 5){igraph <- set.vertex.attribute(igraph, name=names(fin)[i], value=as.character(as.character(fin[,i])[mat]))})
                                      suppressWarnings(for(i in 1:4){igraph <- set.vertex.attribute(igraph, name=names(fin)[i], value=as.numeric(as.character(fin[,i])[mat]))})
                                      
                                      graphs[[kpheno]] <- igraph
                                      graph.names[[kpheno]] <- paste("igraph", phenotypes[kpheno], sep="_")
                                      names(graphs) <- graph.names

                                      
  }
  

  
  return(graphs)
}
