graphParameters <- function(igraph, vertex.attributes=NULL, barcode.value=NULL, est.value=NULL, rnaseqlog2.value=NULL, rnaseq.value=NULL, na.value=TRUE){

  
  igraph <- subUniRemover(igraph=igraph)
  

  
  g <- igraph
  
  E(g)$color <- "black"
  E(g)$width <- 1
  
  if(is.null(get.vertex.attribute(name="size", igraph))){
    
    V(g)$size <- 8
    
  }
  
  for(i in 1:length(E(g)$Intersection)){
    
    
    if(is.na(E(g)$Intersection[i] == TRUE)){
      E(g)$Intersection[i] <- "NA"
    }
    
  }
  
  E(g)[ Intersection =="TRUE"]$width <- 2
  
  E(g)[Subtype == "activation"]$color <- "blue"
  E(g)[Subtype == "inhibition"]$color <- "red"
  E(g)[Subtype == "expression"]$color <- "green"
  E(g)[Subtype == "phosphorylation"]$color <- "orange"
  E(g)[Subtype == "dephosphorylation" || Subtype == "repression" || Subtype == "ubiquination" ]$color <- "yellow"
  
  V(g)$color <- "white"
  
  network.parameters.save <- list()
  igraph.reduced <- g
  igraph <- g
  
  
  
for(n.attr in 1:length(vertex.attributes)){  

  vertex.attribute.run <- vertex.attributes[n.attr]
  
  value.vertex <- get.vertex.attribute(graph=igraph.reduced, name=vertex.attribute.run)
  
  if(length(grep("barcode", vertex.attribute.run))>0){
    if(!is.null(barcode.value)){
    value.selection <- as.numeric(value.vertex)>barcode.value 
    value.selection[is.na(value.selection)] <- na.value
    value.name <- get.vertex.attribute(graph=igraph.reduced, name="name")[!value.selection]
    igraph.reduced <- delete.vertices(igraph.reduced, value.name)
    
    }
  }
  
  if(length(grep("est", vertex.attribute.run))>0){
    if(!is.null(est.value)){
    value.selection <- as.numeric(value.vertex)>est.value 
    value.selection[is.na(value.selection)] <- na.value
    value.name <- get.vertex.attribute(graph=igraph.reduced, name="name")[!value.selection]
    
    igraph.reduced <- delete.vertices(igraph.reduced, value.name)
    }
  }
  
  if(length(grep("rnaseq", vertex.attribute.run))>0){
    
    if(!is.null(rnaseqlog2.value)){
      
      value.selection <- log2(as.numeric(value.vertex))>rnaseqlog2.value
      value.selection[is.na(value.selection)] <- na.value
      value.name <- get.vertex.attribute(graph=igraph.reduced, name="name")[!value.selection]
      
      igraph.reduced <- delete.vertices(igraph.reduced, value.name)
      
    }
    
    if(!is.null(rnaseqlog2.value)){
    value.selection <- as.numeric(value.vertex)>rnaseq.value 
    value.selection[is.na(value.selection)] <- na.value
    value.name <- get.vertex.attribute(graph=igraph.reduced, name="name")[!value.selection]
    
    igraph.reduced <- delete.vertices(igraph.reduced, value.name)
    }
  }

degree.g <- igraph::degree(igraph.reduced)
betweenness.g <- igraph::betweenness(igraph.reduced)
eigenvector.g <- igraph::evcent(igraph.reduced)$vector
clustering.coefficient.g <- igraph::transitivity(igraph.reduced, type="local")

network.parameters <- cbind(degree.g,betweenness.g, eigenvector.g, clustering.coefficient.g)

network.parameters <- network.parameters[order(network.parameters[,1], decreasing=TRUE),]

  network.parameters.save[[n.attr]] <- network.parameters
  names(network.parameters.save)[n.attr] <- vertex.attribute.run
  
}
  return.list <- list()
  return.list[[1]] <- igraph.reduced
  return.list[[2]] <- network.parameters.save
  names(return.list) <- c("Reducedgraph", "NetworkParameters")


  
return(return.list)

}
