\name{IDmappingFunction}
\alias{IDmappingFunction}
\title{
Creation of a referenceTable to map UniprotKB-IDs identifiers to KEGG-IDs and Unigene-IDs
}
\description{
This functions creates a referenceTable to map Uniprot-IDs to other important identifiers. It uses directly the idmapping-data of the Uniprot-database. The referenceTable is important in the Path2enet-package because this identifiers link Unigene-IDs and KEGG-IDs with the UniprotKB-IDs. The UniprotKB-IDs are the keyidentifier to build the tissue specific networks.    
}
\usage{
IDmappingFunction(directory = NULL, tradfcompl = NULL, org = NULL, brainarray=NULL, uniprot=NULL)
}

\arguments{
  \item{directory}{
This is the path the function uses to store the downloaded idmapping table of Uniprot. 
}
  \item{tradfcompl}{
The path to the idmapping table if it is already downloaded manually. 
}
  \item{org}{
The abbrevation Uniprot uses to specify an organism. Uniprot provides idmapping table of ARATH, CAEEL, CHICK, DANRE, DICDI, DROME, ECOLI, HUMAN, MOUSE, RAT, SCHIPO and YEAST. 
}
  \item{brainarray}{
The path to the brainarray file the function should use to create the annotation table. The files are located http://brainarray.mbni.med.umich.edu/Brainarray/Database/CustomCDF/. Here you have to select the microarray platform like hugene10st or HGU133Plus2. You have to download the archive of the category Z (Zip of CDF, Seq, Map, Desc). The path to the included file HGU133Plus2_Hs_ENSG_mapping.txt has to be the argument of this function. }
  \item{uniprot}{
The path to the Reviewd (Swiss-Prot) fasta table of the uniprot website. Go to http://www.uniprot.org/downloads and download the fasta uniprot_sprot.fasta.gz. Extract the file and uniprot_sprot.fasta. The argument ist /path/uniprot_sprot.fasta. 
}
}
\value{

\item{referenceTable }{A data frame which stores UniprotID, GeneID, KEGG-ID, UniProtKB-ID and UniGeneID}

\item{referenceTableAffy }{A data frame which stores UniprotID, GeneID, KEGG-ID, UniProtKB-ID and UniGeneID}

}
\references{
Look for specific abbrevations on ftp://ftp.uniprot.org/pub/databases/uniprot/current _release/knowledgebase/idmapping/by_organism/ and http://www.uniprot.org/ for ID Mapping. 
}
\author{
Conrad Droste
}


\examples{

#The function with this parameters downloads the Rat_*_idmapping.dat.gz file and stores it in the "/tmp/" directory. Then it creates the ID-Mapping table (referenceTable).

referenceTable <- IDmappingFunction(directory="/tmp/", tradfcompl=NULL,  org = "HUMAN")

}

\keyword{ data }

