\name{KeggXML2SqlDatabase}
\alias{KeggXML2SqlDatabase}

\title{
Construction of a MySQL-database based on KGML- and Keggbr-files 
}
\description{
This function: 1.) gets KGML and KeggBr files 2.) parses these files 3.) loads the provided data into a SQL-Database 4.) builds the database. If the option grant is set to "yes", it creates at the same time a DB-user for the database. 
}
\usage{
KeggXML2SqlDatabase(user=NULL,host=NULL, driver="MySQL",password=NULL,grant="FALSE",grant.name="KeggSQL",grant.pw="KeggSQL",directory=NULL,database=NULL, getKGML=FALSE, tricode=NULL, kegbr=NULL, referenceTable=NULL)
}

\arguments{
  \item{user}{
The name of the user of the database. The user needs sufficient rights to create a new database. If the parameter "grant" is "yes", the user needs rights to create a user as well.  Normally it is the root user of the database. 
}
  \item{host}{
The location of the database, like "localhost"
}
\item{driver}{
The function DBI needs a Driver to connect to the database. If you use a MySQL database to store the information of KGML-files, the driver is "MySQL". 
}
  \item{password}{
The password of user of the database who connects to it. This parameter can be NULL if the user does not have a password. 
}
  \item{grant}{
If you set this parameter "yes" this function creates a user with all rights regarded to the created database.
}
  \item{grant.name}{
Name of the user the function creates. 
}
  \item{grant.pw}{
Password of the user the function creates. 
}
  \item{directory}{
The directory of the KGML-Files and KeggBR-file. If getKGML is set to TRUE, this is the directory the function stores the files it downloads.  
}
  \item{database}{
Name of the database the function creates.
}
  \item{getKGML}{
TRUE -> download KGML and KeggBR files.
FALSE or NULL -> Use the stored files in the selected directory. 
}
  \item{tricode}{
The Tri-Code of the KGML files. "hsa" stands for example for human. 
}
  \item{kegbr}{
NULL -> The function downloads the latest keggbr-file KEGG provides OR 
Path to the directory in which the keggBR-file is stored. 
}
  \item{referenceTable}{
The function uses this table to map KeggIDs to UniprotIDs. \code{\link[path2enet:IDmappingFunction]{ generates the table suitable for the annotation.}} You can also call data(referenceTable). 
}
}
\details{
You should only use the getKGML-function if you are in posession of a licence to use KEGG-data. Otherwise please use KGML files which are already in your posession. 
}
\value{
This function returns "TRUE" if the function could create the database.
}
\references{
Kanehisa, M. and Goto, S.; KEGG: Kyoto Encyclopedia of Genes and Genomes. Nucleic Acids Res. 28, 27-30 (2000).
}
\author{
Conrad Friedrich Droste 
}

\examples{
##Set the specific vlues of your MySQL-database and the files of the KEGG database.

\dontrun{
KeggXML2SqlDatabase(user="root", host="localhost", driver="MySQL", password="", grant="yes", grant.name="KeggSQL", grant.pw="KeggSQL", directory="", database="KeggSQL", getKGML="/directory/with/KGML-files", tricode="hsa", kegbr="/path/to/keggbr")
}
  
}

\keyword{ KEGG }
\keyword{ KGML-Files }
