\name{addFunParalogs}
\alias{addFunParalogs}

\title{
Colorise functional paralogs in an igraph-object
}
\description{
The function searches for FunctionalParalogs in the KEGG-Database. It sets a vertex.attribute to the igraph object with this data. It also give the same color to the FunctionalParalogs in the graphical representation. This helps to compare other vertex.attributes of the FunctionalParalogs in the graph. 
}
\usage{
addFunParalogs(igraph = igraph, dbDriver = "MySQL", dbUser = "path2enet", dbHost = "10.10.10.118", dbName = "KeggSQL", password = "path2enet", dbData = "KeggDatabase", paraName = "FunctionalParalogs")
}

\arguments{
  \item{igraph}{
An igraph-object with Uniprot-Swissprot identifiers as "name" vertex.attribute. }
  \item{dbDriver}{
The function DBI needs a Driver to connect to the database. If you use a MySQL database to store the information of KGML-files, the driver is "MySQL".
}
  \item{dbUser}{
To connect to the database the function needs a registered database user which has the sufficient rights to use the "select" statement in order to obtain data of the databse.
}
  \item{dbHost}{
The location of the hosted database. Normally this value is localhost or the specific IP of the database.
}
  \item{dbName}{
The name of the database which stores the information of the KGML files.  
}
  \item{password}{
The password of the database of the user to connect to the database. 
}
  \item{dbData}{
The table of the database used to search for FunctionalParalogs. 
}
  \item{paraName}{
The name of the vertex.attribute the function should store the data of the FunctionalParalogs into. 
}
}
\details{

}
\value{
The function returns the submited igraph object with the additional information on similar nodes in the KEGG-Pathway database loaded in the vertex attribute the user entered in the paraName-parameter.

}
\references{
Kanehisa, M. and Goto, S.; KEGG: Kyoto Encyclopedia of Genes and Genomes. Nucleic Acids Res. 28, 27-30 (2000).
}
\author{
Conrad Friedich Droste
}
\note{
Unfortunately in a large amount of groups of FunctionalParalogs some share colors which are really similar. Use the \code{get.vertex.attribute(igraph, name=paraName)} to see the different groups. 
}

\seealso{
See \code{\link[Path2enet:KeggXML2SqlDatabase]{KeggXML2SqlDatabase}} for information to create the database. 
}
\examples{

\dontrun{
#Notch Signaling Pathway
path2enet <- path2net(dbDriver="MySQL", dbUser="path2enet", dbHost="10.10.10.118", dbName="KeggSQL", password="path2enet", Pathwaytitle="Notch Signaling Pathway", dbData="Relations", dbGlobal="SignalPathwayrelation",  Local="TRUE", Directory="/tmp/",barcode="TRUE")

#Notch Signaling Pathway
notch.graph <- path2enet$Graphs$PPI_PATHWlocal$PATHWlocal2PPI

#FunctionalParalogs added
notch.graph.fun <- addFunParalogs(notch.graph , paraName="FunctionalParalogs")

#Plot the graph
plot(notch.graph.fun)

#Plot without UniprotKB-suffix
plot(subUniRemover(notch.graph.fun))
}

}

\keyword{ ~kwd1 }
\keyword{ ~kwd2 }
