\name{createEstByTissue}
\alias{createEstByTissue}
\title{
Creation of tissue Specific Expression Sequence Tag tables
}
\description{
This function creates data frames which relates the number of ESTs (clones) of a gene with the tissues where it is expressed. This allows to create tissue specific networks in Path2enet
}
\usage{
createEstByTissue(dbDriver = NULL, dbUser = NULL, dbHost = NULL, password = NULL, dbData = NULL, cancer_source = NULL, developmental_stage = "adult", referenceTable=NULL, check = NULL)
}
\arguments{
  \item{dbDriver}{
The function DBI needs a Driver to connect to the database. If you use a MySQL database to store the information of KGML-files, the driver is "MySQL".
}
  \item{dbUser}{
To connect to the database the function needs a registered database user which has the sufficient rights to use the "select" statement in order to obtain data of the databse.
}
  \item{dbHost}{
The location of the hosted database. Normally this value is localhost or the specific IP of the database.
}
  \item{password}{
The password of the database user to access the database.
}
  \item{dbData}{
The name of the database the function mkESTdb creates.
}
  \item{cancer_source}{
This paramater is a filter which selects ESTs of a certain origin. This could be for example "normal" or "lymphoma". Set the parameter check to TRUE to see all "cancer_sources". You can use a character string to select various origins. Separate the characters with "','" for example "normal','lymphoma"
}
  \item{developmental_stage}{
This paramater is a filter which selects ESTs of a certain developmental stage. This could be for example "adult" or "fetus". Set the parameter check to TRUE to see all "developmental_stages". You can use a character string to select various origins. Separate the characters with "','" for example "fetus','adult"
}

  \item{referenceTable}{
This parameter should store the referenceTable to map the IDs. Please check the function IDmapping for more information. 
}

  \item{check}{
This parameter returns data frames with all developmental stages and origins available in the data set. 
}
}
\value{
If check is TRUE the function returns a list with two data frames 
\item{ developmental_stage }{ A list of developmental stages available in the data set  }
\item{ cancer_source }{ A list of cancer sources available in the data set  }

If check is NULL (default) the function returns a list with two data frames 
\item{ est_by_genetissue }{ A data frame which relates the Unigene identifiers with the number of ESTs expressed in a tissue  }
\item{ est_by_symboltissue }{  A data frame which relates the Genesymbol identifiers with the number of ESTs expressed in a tissue }

If the user selecs a referenceTable with UniprotKB-IDs  the function returns an additional data frames

\item{ est_by_uniprotidtissu }{  A data frame which relates the UniprotKB identifiers with the number of ESTs expressed in a tissue. This is necessary to create tissue specific networks with the Path2enet-tool. The function IDmappingFunction creates the needed referenceTable.}

}
\references{
To find more information about the EST data the Unigene database provides, please visit http://www.ncbi.nlm.nih.gov/unigene
}
\author{
Conrad Droste
}


\seealso{
\code{\link[Path2enet:IDmappingFunction]{IDmappingFunction}}
}
\examples{

\dontrun{
#First you can look for all origins and developmental stages available

origins_development <- createEstByTissue(dbDriver="MySQL", dbHost="localhost", dbUser="root", password="pw", dbData="Unigene", check="TRUE")

#Then you can select the origins and development stages you like

result <- createEstByTissue(dbDriver="MySQL", dbHost="localhost", dbUser="root", password="pw", dbData="Unigene", cancer_source="normal', 'lymphoma", developmental_stage="adult','fetus")

#Create the table with UniprotKB-Identifier. 

result <- createEstByTissue(dbDriver="MySQL", dbHost="localhost", dbUser="root", password="conrad", dbData="Unigene2013", cancer_source="normal", developmental_stage="fetus", referenceTable)
}
}
\keyword{ data }

