\name{expParaGraph}
\alias{expParaGraph}

\title{
Comparing expression values of funcional paralogs of a network to each other
}
\description{
The function compares the expression value of functional paralogs (based on the KEGG-database) to each other. The function looks for entries in the KeggSQL-database which share in one or more pathways the same interactions and identifier. The KEGG PATHWAY data replaces these nodes with the same Displayname in their pathway representation. Than the function selects the functional paralogs which share the same interactions in the graph. Then it calculates the z-score, mean, and standard deviation of the expression value of these nodes. The function stores the results as vertex.attributes "expression", "zsore-para", "mean-para", "sd-para" in the graph. The function also stores the names of the functional paralogs in the vertex.attribute "Paralogs". The function generates one graphs per phenotype with these attributes. The function expPhenoGraph uses the output to generate a graphical presentation of the results of the \code{\link[Path2enet:expPhenoGraph]{expPhenoGraph}} function.     
}
\usage{
expParaGraph(igraph, expr, phenotype, dbDriver = "MySQL", dbUser = "root", dbHost = "localhost", dbName = "KeggSQL", password = password)
}

\arguments{
  \item{igraph}{
An igraph-object the function path2enet has generated. 
}
  \item{expr}{
Expression set with ensemble gene identifier as featureNames.
}
  \item{phenotype}{
The name of column of the pData(expr) which stores the information on phenotypes.
}
  \item{dbDriver}{
The function DBI needs a Driver to connect to the database. If you use a MySQL database to store the information of KGML-files, the driver is "MySQL". 
}
  \item{dbUser}{
To connect to the database the function needs a registered database user which has the sufficient rights to use the "select" statement in order to obtain data of the databse.
}
  \item{dbHost}{
The location of the hosted database. Normally this value is localhost or the specific IP of the database.
}
  \item{dbName}{
The name of the database which stores the KGML-files. 
}
  \item{password}{
The password of the user of the database who connects to it. 
}
}
\value{
The result is a list of (number of phenotypes) * graphs. The name of each graph is "igraph_(phenotype)". Please use the function \code{\link[Biobase:phenoData]{pData(expr)}} to see which column stores the phenotype and how the names of the phenotypes are. You can also use \code{names(expParaGraph.results)} to see the names of the graphs the function has generated. The added vertex.attributes of the graph are:
\item{Paralogs}{The group of functional paralogs the function found in the KeggMySQL-database.}
\item{expression }{The expression value of the node in the ExpressionSet}
\item{zscore-para }{The zscore of the expression level of the nodes expParaGraph grouped as functional paralogs}
\item{mean-para }{The mean of the expression level of the nodes expParaGraph grouped as functional paralogs}
\item{sd-para }{The standard deviation of the z-score of the expression level of the nodes expParaGraph grouped as functional paralogs}
Use  \code{list.vertex.attributes(igraph)} to see all vertex attributes. Use  \code{get.vertex.attributes(igraph, "Paralogs") to see a specific attribute (in these case "Paralogs".} 
}
\references{
Kanehisa, M. and Goto, S.; KEGG: Kyoto Encyclopedia of Genes and Genomes. Nucleic Acids Res. 28, 27-30 (2000).
}
\author{
Conrad Friedrich Droste
}

\seealso{
\code{\link[igraph:attributes]{Vertex attributes in Igraph-objects.}}
}
\examples{

}

\keyword{ network }
\keyword{ expression }
