\name{expr2barcode}
\alias{expr2barcode}
\title{
Processing expression data with frma and barcode for network analysis with Path2enet
}
\description{
The function uses frma and barcode to highlight probes which are properly expressed in the Exprssion set. Than it maps affyprobe identifier to Uniprot using the biomaRt function. It calculates the mean of the expression level and the mean of the gene expression barcodes results of the probes annotated to a single UniprotKB identifier. At last it calculates the mean of the barcode results of the different phenotypes.  
}
\usage{
expr2barcode(exprAffy=NULL,  phenotype, referenceTable=NULL, igraph=NULL, cutoff=NULL)
}

\arguments{
  \item{exprAffy}{
Affybatch-object
}
  \item{phenotype}{
The attribute which stores the phenotypes in the Affybatch-object
}
  \item{referenceTable}{
 The mapping table generated with the IDmappingFunction of Path2enet. For the analysis of 'affy_hg_u133a' you can select the table data(referenceTableHGU133A) and for  'affy_hg_u133_plus_2' you can select the table data(referenceTableHGU133Plus). 
}
  \item{igraph}{
An igraph object.
}
  \item{cutoff}{
The function calculates the mean of the probes based on the gene barcode algorithm. This argument filters all genes which have a lower mean value of its probes in the barcode analysis. 1 is the most restrictive value and NULL includes all genes which are not 0. 
}
}
\value{
The function returns a list with three data frames and one igraph-object.
\item{AffyBatchUniprot }{The AffyProbe-Ids of the AffyBatch-object are mapped to UniprotKB-Ids. The mean of the AffyProbe-Ids which mapped to the same UniprotKB-Ids is calculated for each expression experiment. The colum Freq shows how AffyProbe-Ids mapped to one UniprotKB-Id}
\item{BarcodeIndividual }{The data frame includes the mean of the AffyProbeIds of their barcode-value mapped to one UniprotKB-Id. Freq shows the frequency an AffyProbe-Id maps to an UniprotKB-id  }
\item{BarcodePheno }{The data frame includes the mean of the AffyProbeIds of their barcode-value mapped to one UniprotKB-Id for one phenotype. Freq shows the sum of frequency of an AffyProbe-Id mapping to an UniprotKB-id in the phenotype.}
\item{BarcodeGraph }{The function loads the values of BarcodeIndividual and BarcodePheno to an igraph-object as an vertex attribute and returns the igraph-object. }
}
\author{
Conrad Friedrich Droste
}
\note{
Barcode at the moment support the plattforms GPL96 "[HG-U133A] Affymetrix Human Genome U133A Array", GPL570 
"[HG-U133_Plus_2] Affymetrix Human Genome U133 Plus 2.0 Array" and GPL1261 "[Mouse430_2] Affymetrix Mouse Genome 430 2.0 Array".
}


\examples{

\dontrun{

#First get the information of an expression data set of GEO
gse <- getGEO("GSE49541",GSEMatrix=FALSE)
gse49541 <- getGEO("GSE49541",GSEMatrix=TRUE)

#Get the phenotypes of experimental expression data set
phenotypes <- pData(gse49541[[1]])[c("characteristics_ch1", "characteristics_ch1.1")]
characteristics <- as.character(phenotypes$characteristics_ch1)
characteristics <- gsub("Stage: advanced \\(fibrosis stage 3-4\\)", "advanced34", characteristics)
characteristics <- gsub("Stage: mild \\(fibrosis stage 0-1\\)", "mild01", characteristics)
phenotypes$characteristics_ch1 <- characteristics
colnames(phenotypes) <- c("stage", "tissue")

#Downloading the raw data set
getGEOSuppFiles(GEO="GSE49541",makeDirectory=TRUE, baseDir="./Fatty Liver/")
setwd("./GSE49541/")
untar("GSE49541_RAW.tar")
list <- as.character(dir())
lapply(list[grep(".gz", list)], function(x) gunzip(x))

#Loading the data set in R and setting the pData information
cel.files.dir <- dir()
cel.files <- cel.files.dir[grep("\\.CEL$", cel.files.dir)]
fattyliver <- ReadAffy(filenames=cel.files)
pData(fattyliver) <- phenotypes

#Choose an igraph object to load the barcode information of the data set into
data(signal.cancer.local)
data(referenceTableHGU133Plus)
fattyliver.barcode <- expr2barcode(exprAffy=fattyliver,  phenotype, referenceTable=referenceTableHGU133Plus, igraph=signal.cancer.local, cutoff=NULL )
names(fattyliver.barcode)
}

}
\keyword{ network }
\keyword{ expression }
