\name{graphTKplotterTissue}
\alias{graphTKplotterTissue}

\title{
Visualization of Path2enet's tissue specific biological networks
}
\description{
This functions visualizes the igraph-objects Path2enet creates in a tissue specific way. The user can select a tissue like "eye" and only nodes which have at least one Expression Sequence Tag expressed in the selected tissue are represented. The function also creates pdfs to save the plots.
}
\usage{
graphTKplotterTissue(igraph, tissue, name = " ", sub = " ", tkplot = "FALSE", value = 0, type = "Transcript", pdf = "TRUE", layoutComp = NULL, layoutReduced = NULL, directory =  NULL)

}

\arguments{
  \item{igraph}{
An igraph-object the function translateTableKeggID2Uni creates. 
}
  \item{tissue}{
Select a specific tissue like "eye", "heart", etc. use list.vertex.attributes(igraph) to see all possible tissues. 
}
  \item{name}{
Title of the network
}
  \item{sub}{
Subtitle of the network
}
  \item{tkplot}{
If set to "TRUE" the function also creates dynamic plots with the tkplot function. 
}
  \item{value}{
The expression value has to be higher than this argument to be included in the graph. 
}
  \item{type}{
The type of expression value selected. The function uses this argument for the legend of the plot.  
}
  \item{pdf}{
If set to "TRUE" the function creates pdf files with the network. 
}
  \item{layoutComp}{
A created layout of the complete network. 
}
  \item{layoutRmEdges}{
A created layout of the network of the nodes which selected vertex attribute is bigger than zero. 
}
  \item{directory}{
The directory to save the pdf-files
}
}
\value{
The function returns two graphs in form of igraph-objects
\item{graphComplete }{The object has the same nodes as the input graph. The selected vertex.attriutes are highlighted. The function also highlights some edge.attributelike the type of interaction.  }
\item{graphReduced }{In this object all nodes whose selected.vertex attribute is equal to 0 are removed. In the graph the same attributes than in the complete graph are highlighted. }
}
\author{
Conrad Droste
}


\seealso{
To view the structure of the Path2enet-igraph-object please look the help file of translateTableKeggID2Uni.  
\code{\link{translateTableKeggID2Uni}}, 
}
\examples{

\dontrun{
#Generate a graph object with tissue specific vertex.attributes
path2enet <- path2net(dbDriver="MySQL", dbUser="path2enet", dbHost="10.10.10.118", dbName="KeggSQL", password="path2enet", Pathwaytitle="Notch Signaling Pathway", dbData="Relations", dbGlobal="SignalPathwayrelation",  Local="TRUE", Directory="/tmp/",barcode="TRUE")

#Highlight a vertex attribute
unitissue_nerve.graphs <- graphTKplotterTissue(igraph=path2enet$Graphs$PPI_PATHWlocal$PATHWlocal2PPI, tissue="unigene_lung", name="Nerve EST-Unigene Database", sub="Notch Signaling Pathway", tkplot="FALSE", directory="/tmp/")

#Plot the graph
plot(unitissue_nerve.graphs["graphComplete"])
plot(unitissue_nerve.graphs["graphReduced"])
}
}

\keyword{ network }

