\name{mkESTdb}
\alias{mkESTdb}

\title{
Creation of a database based on EST-data of the Unigene database
}
\description{
This function creates a Expression Sequencence Tags of the Unigene databse. The function downloads and parses the files *.lib.info.gz, *.data.gz of the selected species and generates the database. It combines the values to get tissue specific data. The function creates the tables est, est_by_genetissue, eset_by_symboltissue, gene, gene_est_tissue, library and tissue  of the Unigene-Database. 
}
\usage{
mkESTdb(dbDriver = NULL, dbUser = NULL, dbHost = NULL, password = NULL, directory = NULL, dbData = NULL, ESTdataexits = FALSE, name = NULL, species = NULL)
}

\arguments{
  \item{dbDriver}{
The function DBI needs a Driver to connect to the database. If you use a MySQL database to store the information of KGML-files, the driver is "MySQL". 
}
  \item{dbUser}{
To connect to the database the function needs a registered database user which has the sufficient rights to use the "select" statement in order to obtain data of the databse.
}
  \item{dbHost}{
The location of the hosted database. Normally this value is localhost or the specific IP of the database.
}
  \item{password}{
The password of the database user to access the database.
}
  \item{directory}{
The function uses this directory to load or store the EST data files. 
}
  \item{dbData}{
The name of the database the function mkESTdb creates.   
}
  \item{ESTdataexits}{
Set this parameter to true, if you downloaded the EST (Expression Sequencence Tags) files (*.lib.info.gz, *.data.gz) from Unigene to build the EST-database. 
}
  \item{name}{
The name of the species like "Homo_sapiens". 
}
  \item{species}{
Abbrevation of Unigene database of the species like "Hs.". 
}
}

\value{

\item{result }{TRUE if the function could create the EST-database.}
\item{est }{This table stores the information which describes the Expression Sequencence Tags: sec_est (inner ID of the table), sec_gene (Unigene-ID),library_id and clone of the *.data-files.  }
\item{gene }{This table stores the information which describes the gene associated with ESTs: sec_gene (inner ID of the table), id (Unigene-ID),title (full name of the gene) and gene (Gene Symbol), cytoband (cytobands to locate the gene on the chromosome), geneid (GeneID of the gene), express(tissue where the gene is expressed), restrexpr (cellular type / stage in which the EST is expressed), chromosome (chromosome of the gene)}
\item{est_by_genetissue }{This table stores id (Unigene-ID), tissue and count(clone) (number of clones) }
\item{est_by_symboltissue }{This table stores gene (Genesymbol), tissue and count(clone) (number of clones)}
\item{library }{This table stores the information of the Unigenge *.lib.info-file: library_id (identifier of the entry in the table), title, tissue, verbatim_tissue, verbatim_developmental_stage, cell_line_source, developmental_stage, cancer_source and the vector }
\item{tissue }{This table stores the different tissues of the Unigene-data: description (different tissues of ESTs) }


}
\seealso{
Please go to ftp://ftp.ncbi.nih.gov/repository/UniGene/ to look for the name and abbrevation of the organism in the Unigene database and the documentation of the different entries in its files. 
}
\author{
Conrad Droste
}

\examples{
\dontrun{
#You have to adjust the parameters regarding your database.

mkESTdb(dbDriver="MySQL", dbUser="root", dbHost="localhost", dbData="unigeneEST", directory="dir", species="Hs.", ESTdataexits="FALSE" , name="Homo_sapiens", password="pw")
}
}

\keyword{ data }
