\name{path2enet}
\alias{path2enet}

\title{
Path2enet combining pathway, protein-protein-interaction and tissue specific data into tissue specific networks
}
\description{
Path2enet integrates pathway, protein-protein-interaction information and tissue specific experimental Expression Sequences Tags data into tissue specific networks. The user can build the network out of a list of genes or individual or multiple pathways. The user can choose different pathway subsets, like "Signaling Pathways" or "Disease Pathways" and compare the networks to each other. The functions calculates the parameters Degree, Betweenness, Eigenvector and Clustering_Coefficient of the generated networks. 
}
\usage{
path2enet(dbDriver = "MySQL", dbUser = "KeggSQL", dbHost ="localhost", dbName = "KeggSQL", password = "KeggSQL", dbGlobal = "Normal", dbData = "Relations", GeneID =NULL, KeggID = NULL, PathwayID = NULL, Pathwaytitle =NULL, Subtype = NULL, Proteinreaction = NULL, Local ="TRUE", Directory = "/tmp/", dbPPI = "PPI", barcode =NULL, unitissue = NULL, rnaseq = NULL)
}

\arguments{
  \item{dbDriver}{
The function DBI needs a Driver to connect to the database. If you use a MySQL database to store the information of KGML-files, the driver is "MySQL". 
}
  \item{dbUser}{
To connect to the database the function needs a registered database user which has the sufficient rights to use the "select" statement in order to obtain data of the databse.
}
  \item{dbHost}{
The location of the hosted database. Normally this value is localhost or the specific IP of the database.
}
  \item{dbName}{
The name of the database which stores the KGML-files.
}
  \item{password}{
The password of the database user to access the database. 
}
  \item{dbGlobal}{
The subset of pathways to look for interactions and compare the network using the subset of pathways of dbData.
}
  \item{dbData}{
The subset of pathways to look for interactions and compare the network using the subset of pathways of dbGlobal. The standard is "Relations" which includes all pathways. 
}
  \item{GeneID}{
A character of UniprotKB-IDs separated by " ',' " the user selects to search in the database.
}
  \item{KeggID}{
A character of KeggIDs separated by " ',' " the user selects to search in the database.
}
  \item{PathwayID}{
A character of PathwayIDs separated by " ',' " the user selects to search in the database.
}
  \item{Pathwaytitle}{
A character of Pathwaytitles separated by " ',' " the user selects to search in the database.
}
  \item{Subtype}{
The KGML-files store a subtype of the proteinrelation. Here the user can set up a filter to select only relations of a specific kind like: activation, binding/association, compound, dephosphorylation, dissociation, expression, indirect effect, inhibition, ethylation, missing interaction, phosphorylation, repression, state change or ubiquitination. 
}
  \item{Proteinreaction}{
The KGML-files store a class of relations. Here the user can set up a filter to select only relations of a specific class like: ECrel (Enzyme Compound), GErel (Gene Enzyme), group, maplink, PCrel (Protein Compound) and PPrel (Protein Protein relation)
}
  \item{Local}{
If this parameter is set to "TRUE", only interactions who include both interaction partners in the "GeneID/KeggID" list of genes are used to generate the network.
If it is set to "FALSE" any interaction including only one interaction partner in the "GeneID/KeggID" list of genes are used to generate the netwrok.  
}
  \item{Directory}{
The directory to store the output result.
}
  \item{dbPPI}{
The name of the protein-protein-interaction database the funcion should use. 
}
  \item{barcode}{
The tissue specific data of the Barcode database (http://barcode.luhs.org/) "Homo Sapiens" is integrated in the network. This provides tissue specific information based on many microarray experiments. Use \code{\link[Path2enet:barcodeTissueUni]{barcodeTissueUni}} to see more information about the data set
}
  \item{unitissue}{
The tissue specific data of the Unigene-EST database (ftp://ftp.ncbi.nih.gov/repository/UniGene/) is integrated in the network. This provides tissue specific information based on EST data. Use \code{\link[Path2enet:mkESTdb]{mkESTdb}} to generate your EST-database. 
}
  \item{rnaseq}{
The tissue specific RNA-seq data of the Illumina Body Map 2.0  (http://www.ebi.ac.uk/arrayexpress/experiments/E-MTAB-513/) is integrated in the network. This provides tissue specific information based on RNA-seq experiments of 16 healthy tissues. Use \code{\link[Path2enet:rnaseqTissueUni]{rnaseqTissueUni}} to see more information about the data set. 
}
}
\value{
The results are a list of (1) Graphs and (2) analyzed parameters and (3) the txt-output of the analysis of the graphs and the graphs itself. 
\item{Graphs}{The path2enet function generates three different graphs and compares them to each other to highlight shared interations in the graphs. The generated graphs are:  (i) PPI: is a graph created with stored protein-protein-interactions in the ppi database; (ii) PATHWLocal: is the network generated of the dbData data set of the pathway database; and (iii) PATHWGlobal is the network generated of the dbGlobal data set of the pathway database. Is a list with three sublists with each sublist storing 2 igraph-objects. The sublists are "PPI_PATHWGlobal", "PATHWLocal_PATHWGlobal" and  "PPI_PATHWLocal". }
\item{PPI_PATHWglobal}{Sublist with two graphs: Comparing the PPI and PATHWglobal networks  }
\item{PPI2PATHWglobal}{The protein-protein-interaction network compared to the PATHWglobal network.  }
\item{PATHWglobal2PPI}{The PATHWglobal network compared to the PPI network.}
\item{PATHWlocal_PATHWglobal}{Sublist with two graphs: Comparing the PATHWlocal and PATHWglobal networks  }
\item{PATHWlocal2PATHWglobal}{PATHWlocal compared to the PATHWglobal network.  }
\item{PATHWglobal2PATHWlocal}{The PATHWglobal network compared to the PATHWlocal network.}
\item{PPI_PATHWlocal}{Sublist with two graphs: Comparing the PPI and PATHWlocal networks  }
\item{PPI2PATHWlocal}{The protein-protein-interaction network compared to the PATHWlocal network.  }
\item{PATHWlocal2PPI}{The PATHWlocal network compared to the PPI network.}
\item{Analysed_Graphs }{This list stores the edge lists of PATHLocal and six results of the statistical analysis of the graphs. The functions calculates the network parameters Degree, Betweenness, Eigenvector and Clustering_Coefficient. The function analysis the graphs generated of the data set of the pathway database in two different ways. One way is to connect all nodes annotated to a complex to one node (group of nodes - "withGroups"). This is done to find interconnected hubs (inner hubs) besides complexes. The other way is to treat every node and its relations individually.}
\item{EdgeList_PATHWlocal_withGroups}{EdgeList of PATHWlocal with nodes combined to groups.}
\item{EdgeList_withSubtype_withoutGroups}{EdgeList of PATHWlocal with individual nodes and the kind of the relation the nodes in the pathway have. }
\item{Analysed_PATHWlocal_KeggIDs_withGroups}{The analysis of PATHWlocal with groups and KEGG identifiers. }
\item{Analysed_PATHWlocal_UniprotKBIds_withGroups}{The analysis of PATHWlocal with groups and UniprotKB identifiers. }
\item{Analysed_PATHWlocal_UniprotKBIds_withoutGroups}{The analysis of PATHWlocal with every node treated individually in the statistical analysis and UniprotKB identifiers. }
\item{Analysed_PPI}{The analysis of PPI network with every node treated individually in the statistical analysis and UniprotKB identifiers. }
\item{Analysed_PATHWglobal_UniprotKBIds_withGroups}{The analysis of PATHWglobal with groups and UniprotKB identifiers. }

\item{"Analysed_PATHWglobal_UniprotKBIds_withoutGroups}{The analysis of PATHWglobal with every node treated individually in the statistical analysis and UniprotKB identifiers. }

\item{Output}{The output the function stores in the selected "Directory" are forteen .txt-files. The output is seperated in: (i) "EdgeList" of the graph; (ii) the statistical analysis with or withour "groups"; and (iii) pathway related dataset is saved with the KEGG identifiers and the UniprotKB identifiers.}
}
\references{
McCall et al., "The Gene Expression Barocde: leveraging public data repositories to begin cataloging the human and murine transcriptomes" Nucleic Acids Research. 2011 Jan;39(suppl 1):D1011-D1015

Kanehisa, M. and Goto, S.; KEGG: Kyoto Encyclopedia of Genes and Genomes. Nucleic Acids Res. 28, 27-30 (2000).

}
\author{
Conrad Friedrich Droste
}

\examples{
## You have to set the parameters to access the databases first. 
\dontrun{
library(path2enet)
data(barcodeTissueUniP)
data(estTissueUniP)
data(rnaseqTissueUniP)

path2enet <- path2enet(dbDriver="MySQL", dbUser="path2enet", dbHost="localhost", dbName="KeggSQL", password="path2enet", Pathwaytitle="Notch Signaling Pathway", dbData="Relations", dbGlobal="SignalPathwayrelation",  Local="TRUE", Directory="/tmp/",barcode=barcodeTissueUni, unitissue = NULL, rnaseq = NULL )
}
}
\keyword{ ~network }

