\name{referenceNetwork}
\alias{referenceNetwork}

\title{
Generating reference networks based on library and experimental knowledge of EST, Microarray and RNA-seq data
}
\description{
The referenceNetwork function uses networks the path2enet-function generates to create reference networks. Reference networks are networks which EST, Microarray and RNA-seq expression data fullfill the requiremetns of the user. The user can select individual filters for these data sets. This allows to generate tissue or cell specific networks for further network analysis or integration of experimental data sets of the user. 
}
\usage{
referenceNetwork(igraph, vertex.attributes = NULL, barcode.value = NULL, unigene.value = NULL, rnaseqlog2.value = NULL, rnaseq.value = NULL)
}

\arguments{
  \item{igraph}{
An igraph object which stores values of EST, Microarray or RNA-seq expression data. The name of the vertex attributes should start with "unigene_" (EST-value), "barcode_" (Microarray data processed with the \code{\link[frma:barcode]{barcode}} algorithm) or "rnaseq_" (RNA-seq data sets). The prefix of the names say the function which filter rule it should use for the vertex.attribute.  
}
  \item{vertex.attributes}{
A list of vertex.attributes of the igraph-object which store the data sets. use \code{\link[igraph:list.vertex.attributes]{list.vertex.attributes}} to see all attributes of the igraph-object.  
}
  \item{barcode.value}{
The Microarray expression value processed with the \code{\link[frma:barcode]{barcode}} algorithm has to be greater or equal to the given value. The maximal value is 1 the minimum 0. 
}
  \item{unigene.value}{
The EST value has to be greater or equal to the given value. 
}
  \item{rnaseqlog2.value}{
The log2 of the RNAseq-value has to be equal or greater than the selected value. 
}
  \item{rnaseq.value}{
The lRNAseq-value has to be equal or greater than the selected value.
}
}

\value{
The result is a list with one igraph-object (ReferenceGraph) and its network parameters.
\item{ReferenceNetwork }{The function deletes all vertex nodes, which do not fullfill the selected parameters and generates a new network - the ReferenceNetwork. It is an igraph object which stores all attributes of the input igraph object. }
\item{NetworkParameters }{NetowrkParameters is a matrix which stores the degree, betweeenness, eigenvector and clustering.coefficient of the generated ReferenceNetwork.}

}
\references{
The references on the data sets can be found in the documentation of the functions in the seealso section. 
}
\author{
Conrad Friedrich Droste
}

\seealso{
You can find information on the data sets Path2enet provides in the documention of the functions \code{\link[Path2enet:barcodeTissueUni]{barcodeTissueUni}}, code{\link[Path2enet:mkESTdb]{mkESTdb}} and code{\link[Path2enet:rnaseqTissueUni]{rnaseqTissueUni}}
}
\examples{

data(signal.cancer.local)
vcount(signal.cancer.local)
ecount(signal.cancer.local)
#select all liver specific attributes of the network to create a liver specific network
liver.num <- grep("liver", list.vertex.attributes(signal.cancer.local))
liver.attributes <- list.vertex.attributes(signal.cancer.local)[liver.num]
liver.attributes

#Creation of the liver specific network
signal.cancer.local.reference.liver <- referenceNetwork(igraph=signal.cancer.local, vertex.attributes=liver.attributes, barcode.value=0,unigene.value=0,rnaseqlog2.value=1)
signal.cancer.local.reference.liver.network <- signal.cancer.local.reference.liver$ReferenceNetwork
signal.cancer.local.reference.liver.network.parameters <- signal.cancer.local.reference.liver$NetworkParameters
vcount(signal.cancer.local.reference.liver.network)
ecount(signal.cancer.local.reference.liver.network)
}

\keyword{ network }

