\name{searchFunction}
\alias{searchFunction}
\title{
Search in the Path2enet-MySQL database
}
\usage{
searchFunction(dbDriver = "MySQL", dbUser = "KeggSQL", dbHost = "10.10.10.7", dbName = "KeggSQL", password = "KeggSQL", dbData = "Relations", GeneID = NULL, KeggID = NULL, PathwayID = NULL, Pathwaytitle = NULL, Subtype = NULL, Proteinreaction = NULL, selectGeneID = "FALSE", selectDisplayname = "FALSE", selectKeggID = "FALSE", selectALL = "TRUE", selectPathwaytitle = "FALSE", selectFREE = "FALSE", Relations = "FALSE", noNA = "TRUE", Local = FALSE, print = FALSE)
}
\arguments{
  \item{dbDriver}{
The function DBI needs a Driver to connect to the database. If you use a MySQL database to store the information of KGML-files, the driver is "MySQL". 
}
  \item{dbUser}{
To connect to the database the function needs a registered database user which has the sufficient rights to use the "select" statement in order to obtain data of the databse.
}
  \item{dbHost}{
The location of the hosted database. Normally this value is localhost or the specific IP of the database.
}
  \item{dbName}{
The name of the database which stores the KGML-files. 
}
  \item{password}{
The password of the database user to access the database. 
}
  \item{dbData}{
The table of the databse to look for the specific entries. KeggDatabase contains the data of KeggEntries like Pathwaytitle, Pathwayid, GeneID, KeggID, EntryID, Type, Displayname and NrParalogous. Relations contains the data of KeggRelations like Pathwaytitle, Pathwayid, GeneID_1, KeggID_1, Displayname_1, NrParalogous,  GeneID_2, KeggID_2, Displayname_2, NrParalogous2, Proteinreaction, Subtype and Subtype2. 
}
  \item{GeneID}{
A character of UniprotKB-IDs separated by " ',' " the user selects to search in the database. 
}
  \item{KeggID}{
A character of KeggIDs separated by " ',' " the user selects to search in the database.
}
  \item{PathwayID}{
A character of PathwayIDs separated by " ',' " the user selects to search in the database.
}
  \item{Pathwaytitle}{
A character of Pathwaytitles separated by " ',' " the user selects to search in the database.
}
  \item{Subtype}{
The KGML-files store a subtype of the proteinrelation. Here the user can set up a filter to select only relations of a specific kind like: activation, binding/association, compound, dephosphorylation, dissociation, expression, indirect effect, inhibition, ethylation, missing interaction, phosphorylation, repression, state change or ubiquitination. 
}
  \item{Proteinreaction}{
The KGML-files store a class of relations. Here the user can set up a filter to select only relations of a specific class like: ECrel (Enzyme Compound), GErel (Gene Enzyme), group, maplink, PCrel (Protein Compound) and PPrel (Protein Protein relation) 
}
  \item{selectGeneID}{
If the user changes the parameter to "TRUE", the search only returns GeneID-values of the database (GeneID or GeneID_1 / GeneID_2)
}
  \item{selectDisplayname}{
If the user changes the parameter to "TRUE", the search only returns Displayname-values of the database (Displayname or Displayname_1 / Displayname_2)
}
  \item{selectKeggID}{
If the user changes the parameter to "TRUE", the search only returns KeggID-values of the database (KeggID or KeggID_1 / KeggID_2)
}
  \item{selectALL}{
If the parameter is "TRUE" (default), the search returns all informations in the database, which fits the search values. 
}
  \item{selectPathwaytitle}{
If the user changes the parameter to "TRUE", the search only returns the Pathwaytitles of the database which fits the search values.
}
  \item{selectFREE}{
The user can select, which parameters the searchFunction should return, like for example "GeneID_1, KeggID_1"
}
  \item{Relations}{
If the parameter is "TRUE" (default), the user has to select a database talbe for the dbData parameter which stores interactions, like "Relations" or "CancerPathwayrelation". If the user sets this parameter "FALSE" only general information about a gene/protein is returned and the table should not store interactions. Normally the table "KeggData" is recommended. 
}
  \item{noNA}{
This parameter decides if the search returns "NA" values as well. If the sets it "TRUE" the function return "NA" values but the default is "FALSE". 
}
  \item{Local}{
This parameter decides if the search should only return relations if both interaction partners are part of the search-parameter list. This is only important if user wants to search with a list of GeneIDs or KeggIDs. 
}
  \item{print}{
If this paramter is "TRUE" (default), the functions prints the SQL-search term. 
}
}

\value{
\item{ result }{The result of the search in the database with the parameters the user chooses.}
}
\author{
Conrad Droste
}

\examples{
\dontrun{
#search with a character of KEGG-IDs separated with ','
kegglist <- c('hsa:11317' , 'hsa:5986' , 'hsa:51107' , 'hsa:55851' , 'hsa:5663' , 'hsa:5664' , 'hsa:9541' , 'hsa:55534' , 'hsa:84441' , 'hsa:9794' , 'hsa:1487' , 'hsa:1488', 'hsa:1488', 'hsa:3065', 'hsa:3066' )

#In which pathway a list of genes is present
searchFunction(dbDriver="MySQL", dbUser="path2enet", dbHost="10.10.10.118", dbName="KeggSQL", password="path2enet", dbData="KeggDatabase", KeggID=kegglist, selectALL='TRUE',  Local="FALSE")

#Which kind of Relations has the list of genes in Cancer annotated pathways 
searchFunction(dbDriver="MySQL", dbUser="path2enet", dbHost="10.10.10.118", dbName="KeggSQL", password="path2enet", dbData="Cancers", KeggID=kegglist, selectALL='TRUE',  Local="FALSE", Relations="TRUE")

#Which kind of inter relations has the list of genes in Cancer annotated pathways or Normal
searchFunction(dbDriver="MySQL", dbUser="path2enet", dbHost="10.10.10.118", dbName="KeggSQL", password="path2enet", dbData="Normal", KeggID=kegglist, selectALL='TRUE',  Local="TRUE", Relations="TRUE")

#Entries in the KEGG Database
#Relations between the genes in the gene list

genelist <- c( "4EBP1_HUMAN", "AAPK1_HUMAN" ,"AAPK2_HUMAN" ,"AKT1_HUMAN" , "AKT2_HUMAN" , "AKT3_HUMAN" , "AKTS1_HUMAN" ,"I4E1B_HUMAN" ,"IF4E2_HUMAN" ,"IF4E_HUMAN" , "MTOR_HUMAN",  "TSC2_HUMAN" , "P55G_HUMAN" ,"P85A_HUMAN")
normal.inter <- searchFunction(dbDriver="MySQL", dbUser="path2enet", dbHost="10.10.10.118", dbName="KeggSQL", password="path2enet", dbData="Relations", print="FALSE" , GeneID=genelist , Relations="TRUE", selectGeneID="TRUE", Local="TRUE")

#Entries in the KEGG Database, SignalingPathways
#Complete Entry
signal.compl <- searchFunction(dbDriver="MySQL", dbUser="path2enet", dbHost="10.10.10.118", dbName="KeggSQL", password="path2enet", dbData="SignalPathwayrelation", print="FALSE" , GeneID=genelist , Relations="TRUE")

#Only Gene-Gene Relations
signal.geneID <- searchFunction(dbDriver="MySQL", dbUser="path2enet", dbHost="10.10.10.118", dbName="KeggSQL", password="path2enet", dbData="SignalPathwayrelation", print="FALSE" , GeneID=genelist , Relations="TRUE", selectGeneID="TRUE")
}
}

\keyword{ data }

