\name{searchParalogos}
\alias{searchParalogos}
\title{
Search for possible Paralogos in the KEGGrelated database of the Path2ente-package
}
\description{
The KEGG database provides sometimes for one note of the network several genes. For example Kegg replaces in the "NOTCH SIGNALING PATHWAY" of Homo sapiens four NOTCH genes (NOTCH1, NOTCH2, NOTCH3, NOTCH4) with the displayname "Notch". This makes the pathway easier to read. This function collects and shows the genes KEGG replaces with the same displayname. In many cases these genes are paralogos, but this is not necessary. 
}
\usage{
searchParalogos(dbDriver = "MySQL", dbUser = "KeggSQL", dbHost = "10.10.10.7", dbName = "KeggSQL", password = "KeggSQL", dbData = "KeggDatabase", GeneID = " ", KeggID = " ", print= "FALSE")
}
\arguments{
  \item{dbDriver}{
The function DBI needs a Driver to connect to the database. If you use a MySQL database to store the information of KGML-files, the driver is "MySQL". 
}
  \item{dbUser}{
To connect to the database the function needs a registered database user which has the sufficient rights to use the "select" statement in order to obtain data of the databse.
}
  \item{dbHost}{
The location of the hosted database. Normally this value is localhost or the specific IP of the database.
}
  \item{dbName}{
The name of the database which stores the KGML-files. 
}
  \item{password}{
The password of the database user to access the database. 
}
  \item{dbData}{
The table of the databse to look f or possible Paralogos. In this case KeggDatabase is set to default to look for possible Paralogos in the whole KEGG-related database the Path2enet provides. 
}
  \item{GeneID}{
The user can chose a GeneID to look for possible paralogos in the dbData-table of the dbName databse.
}
  \item{KeggID}{
The user can chose one KEGG-ID to look for possible paralogos in the dbData-table of the dbName databse.
}
  \item{print}{
If this paramter is "TRUE" (default), the functions prints the SQL-search term. 
}
}
\value{
\item{ Paralogos }{The function returns a dataframe of genes which are replaced with the same displayname in the KEGG PATHWAY database (KGML-files). These are often paralogos but this is not necessary. }

}
\author{
Conrad Droste
}
\examples{
\dontrun{
# Select the parameters to connect to your database and choose a user which has the right to use the "select" command in the database. 
#GeneID
searchParalogos(dbDriver="MySQL", dbUser="path2enet", dbHost="10.10.10.118", dbName="KeggSQL", password="path2enet",dbData="KeggDatabase",GeneID="AKT1_HUMAN", print="FALSE")
#KEGG-ID
searchParalogos(dbDriver="MySQL", dbUser="path2enet", dbHost="10.10.10.118", dbName="KeggSQL", password="path2enet",dbData="KeggDatabase",KeggID = "hsa:4851", print="FALSE")
}

}

\keyword{methods}

